#!/bin/bash

# Running on chrysalis

#SBATCH  --job-name=ts_atm_daily_180x360_aave_0011-0020-0010
#SBATCH  --account=e3sm
#SBATCH  --nodes=1
#SBATCH  --output=test_bash_generation_output/post/scripts/ts_atm_daily_180x360_aave_0011-0020-0010.o%j
#SBATCH  --exclusive
#SBATCH  --time=02:00:00


#SBATCH  --partition=haswell


...

# Turn on debug output if needed
debug=False
if [[ "${debug,,}" == "true" ]]; then
  set -x
fi

# Script dir
cd test_bash_generation_output/post/scripts

# Get jobid
id=${SLURM_JOBID}

# Update status file
STARTTIME=$(date +%s)
echo "RUNNING ${id}" > ts_atm_daily_180x360_aave_0011-0020-0010.status

# Create temporary workdir
workdir=`mktemp -d tmp.${id}.XXXX`
cd ${workdir}

# Create symbolic links to input files
input=./archive/atm/hist
for (( year=11; year<=20; year++ ))
do
  YYYY=`printf "%04d" ${year}`
  for file in ${input}/case_name.eam.h1.${YYYY}-*.nc
  do
    ln -s ${file} .
  done
done

ts_fmt=ts_only
echo $ts_fmt
# For non-monthly input files, need to add the last file of the previous year
year=10
YYYY=`printf "%04d" ${year}`
mapfile -t files < <( ls ${input}/case_name.eam.h1.${YYYY}-*.nc 2> /dev/null )
if [ ${#files[@]} -ne 0 ]
then
  ln -s ${files[-1]} .
fi
# as well as first file of next year to ensure that first and last years are complete
year=21
YYYY=`printf "%04d" ${year}`
mapfile -t files < <( ls ${input}/case_name.eam.h1.${YYYY}-*.nc 2> /dev/null )
if [ ${#files[@]} -ne 0 ]
then
  ln -s ${files[0]} .
fi


vars=PRECT

ls case_name.eam.h1.????-*.nc > input.txt
if grep -q "*" input.txt; then
  cd test_bash_generation_output/post/scripts
  echo 'Missing input files'
  echo 'ERROR (1)' > ts_atm_daily_180x360_aave_0011-0020-0010.status
  exit 1
fi
# Generate time series files
# If the user-defined parameter "vars" is "", then ${vars}, defined above, will be too.
cat input.txt | ncclimo \
-c case_name \
-v ${vars} \
--split \
--yr_srt=11 \
--yr_end=20 \
--ypf=10 \
--map=/home/ac.zender/data/maps/map_ne30pg2_to_cmip6_180x360_aave.20200201.nc \
-o trash \
-O output \
--clm_md=hfs \
--dpf=30 \
--tpd=1 \
--prc_typ=eam



if [ $? != 0 ]; then
  cd test_bash_generation_output/post/scripts
  echo 'ERROR (2)' > ts_atm_daily_180x360_aave_0011-0020-0010.status
  exit 2
fi

# Move output ts files to final destination
{
  dest=test_bash_generation_output/post/atm/180x360_aave/ts/daily/10yr
  mkdir -p ${dest}
  mv output/*.nc ${dest}
}
if [ $? != 0 ]; then
  cd test_bash_generation_output/post/scripts
  echo 'ERROR (3)' > ts_atm_daily_180x360_aave_0011-0020-0010.status
  exit 3
fi

# Delete temporary workdir
cd ..
if [[ "${debug,,}" != "true" ]]; then
  rm -rf ${workdir}
fi

# Update status file and exit

ENDTIME=$(date +%s)
ELAPSEDTIME=$(($ENDTIME - $STARTTIME))

echo ==============================================
echo "Elapsed time: $ELAPSEDTIME seconds"
echo ==============================================
rm -f ts_atm_daily_180x360_aave_0011-0020-0010.status
echo 'OK' > ts_atm_daily_180x360_aave_0011-0020-0010.status
exit 0